@@ -134,7 +134,7 @@ setGeneric("pileup",
         standardGeneric("pileup"),
     signature=signature("file"))
 
-setGeneric(".asSpace", function(x) standardGeneric(".asSpace"))
+setGeneric(".asRegions", function(x) standardGeneric(".asRegions"))
 
 setGeneric("applyPileups", function(files, FUN, ..., param)
            standardGeneric("applyPileups"),
@@ -150,6 +150,14 @@ setGeneric("index",
 setGeneric("index<-",
            function(object, ..., value) standardGeneric("index<-"))
 
+setGeneric("gzindex",
+           function(object, asNA=TRUE)
+           standardGeneric("gzindex"),
+           signature="object")
+
+setGeneric("gzindex<-",
+           function(object, value) standardGeneric("gzindex<-"))
+
 setGeneric("yieldSize",
            function(object, ...) standardGeneric("yieldSize"))
 
