@@ -13,13 +13,14 @@
 }
 
 .io_check_exists <-
-    function(file)
+    function(files)
 {
-    if (!length(file))
-        stop("'file' is length(0)")
-    idx <- !grepl("^(ftp)|(http)://", file) & !is.na(file)
-    if (!all(sapply(file[idx], file.exists))) {
-        msg <- paste(sprintf("'%s'", file[idx]), collapse="\n  ")
+    if (!length(files))
+        stop("'files' is length(0)")
+    idx <- !grepl("^(ftp|http|https)://", files) & !is.na(files)
+    test <- file.exists(files[idx])
+    if (!all(test)) {
+        msg <- paste0(sQuote(files[idx][!test]), collapse = "\n  ")
         stop("file(s) do not exist:\n  ", msg)
     }
 }
@@ -30,8 +31,11 @@
 .normalizePath <-
     function(path)
 {
-    if (is(path, "RsamtoolsFile"))
+    if (is(path, "RsamtoolsFile")) {
         path <- path(path)
+    } else {
+        path <- as.character(path)
+    }
     idx <- !grepl("^(ftp)|(http)://", path) & !is.na(path)
     ## expand ~/, but don't chase links (i.e., don't normalizePath())
     path[idx] <- path.expand(path[idx])
